==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridFilterExpressionsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterExpressionsEventArgsDescription } from "./GridFilterExpressionsEventArgsDescription";
/**
 * @hidden
 */
export let GridFilterExpressionsEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterExpressionsEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterExpressionsEventArgsDescriptionMetadata.a == null) {
                GridFilterExpressionsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterExpressionsEventArgsDescriptionMetadata.c(GridFilterExpressionsEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridFilterExpressionsEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridFilterExpressionsEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("FilterExpressions", "Collection:FilterExpression:FilterExpressionCollection:FilterExpression");
        }
        static d(a) {
            GridFilterExpressionsEventArgsDescriptionMetadata.b(a);
            a.ad("GridFilterExpressionsEventArgs", () => new GridFilterExpressionsEventArgsDescription());
            a.ac("GridFilterExpressionsEventArgs", GridFilterExpressionsEventArgsDescriptionMetadata.a);
        }
    }
    GridFilterExpressionsEventArgsDescriptionMetadata.$t = markType(GridFilterExpressionsEventArgsDescriptionMetadata, 'GridFilterExpressionsEventArgsDescriptionMetadata');
    GridFilterExpressionsEventArgsDescriptionMetadata.a = null;
    return GridFilterExpressionsEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridFilterExpressionsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterExpressionsEventArgsDescription } from "./GridFilterExpressionsEventArgsDescription";
/**
 * @hidden
 */
export let GridFilterExpressionsEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterExpressionsEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterExpressionsEventArgsDescriptionMetadata.a == null) {
                GridFilterExpressionsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterExpressionsEventArgsDescriptionMetadata.c(GridFilterExpressionsEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridFilterExpressionsEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridFilterExpressionsEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("FilterExpressions", "Collection:FilterExpression:FilterExpressionCollection:FilterExpression");
        }
        static d(a) {
            GridFilterExpressionsEventArgsDescriptionMetadata.b(a);
            a.ae("GridFilterExpressionsEventArgs", () => new GridFilterExpressionsEventArgsDescription());
            a.ad("GridFilterExpressionsEventArgs", GridFilterExpressionsEventArgsDescriptionMetadata.a);
        }
    }
    GridFilterExpressionsEventArgsDescriptionMetadata.$t = markType(GridFilterExpressionsEventArgsDescriptionMetadata, 'GridFilterExpressionsEventArgsDescriptionMetadata');
    GridFilterExpressionsEventArgsDescriptionMetadata.a = null;
    return GridFilterExpressionsEventArgsDescriptionMetadata;
})();
